@@ -7,8 +7,8 @@ from .__about__ import (
 )
 
 __all__ = [
-    '__version__',
-    '__copyright__',
-    '__credits__',
-    '__packagename__',
+    "__version__",
+    "__copyright__",
+    "__credits__",
+    "__packagename__",
 ]
