@@ -34,7 +34,7 @@ def _build_parser():
     def _to_gb(value):
         scale = {"G": 1, "T": 10 ** 3, "M": 1e-3, "K": 1e-6, "B": 1e-9}
         digits = "".join([c for c in value if c.isdigit()])
-        units = value[len(digits):] or "M"
+        units = value[len(digits) :] or "M"
         return int(digits) * scale[units[0]]
 
     def _drop_sub(value):
@@ -115,9 +115,12 @@ def _build_parser():
         "(https://github.com/bids-standard/pybids/blob/master/bids/layout/config/bids.json)",
     )
     g_bids.add_argument(
-        "--anat-derivatives", action='store', metavar="PATH", type=PathExists,
+        "--anat-derivatives",
+        action="store",
+        metavar="PATH",
+        type=PathExists,
         help="Reuse the anatomical derivatives from another fMRIPrep run or calculated "
-             "with an alternative processing tool (NOT RECOMMENDED)."
+        "with an alternative processing tool (NOT RECOMMENDED).",
     )
 
     g_perfm = parser.add_argument_group("Options to handle performance")
@@ -188,7 +191,7 @@ def _build_parser():
         action="store",
         nargs="+",
         default=[],
-        choices=["fieldmaps", "slicetiming", "sbref"],
+        choices=["fieldmaps", "sbref"],
         help="ignore selected aspects of the input dataset to disable corresponding "
         "parts of the workflow (a space delimited list)",
     )
@@ -216,6 +219,14 @@ use this option without specifying any spatial references. For further details,
 https://www.nipreps.org/dmriprep/en/%s/spaces.html"""
         % (currentv.base_version if is_release else "latest"),
     )
+    g_conf.add_argument(
+        "--dwi2t1w-init",
+        action="store",
+        default="register",
+        choices=["register", "header"],
+        help='Either "register" (the default) to initialize volumes at center or "header"'
+        " to use the header information when coregistering DWI to T1w images.",
+    )
 
     #  ANTs options
     g_ants = parser.add_argument_group("Specific options for ANTs registrations")
